# Image_by_Picture

Description. 
The package image_by_picture is used to:
    Processing
	    - processing_image
	    - image_treatment
	    - salve_image

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install image_by_picture

```bash
pip install image_by_picture
```

## Author
Nequita

## License
[MIT](https://choosealicense.com/licenses/mit/)